cgexplore.terms.TargetBondRange
===============================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetBondRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetBondRange.yield_bonds
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetBondRange.type1
      ~TargetBondRange.type2
      ~TargetBondRange.element1
      ~TargetBondRange.element2
      ~TargetBondRange.bond_rs
      ~TargetBondRange.bond_ks
   
   